Class: Glib::FormStepper::Step
- Inherits:
-
Data
- Object
- Data
- Glib::FormStepper::Step
- Defined in:
- app/controllers/concerns/glib/form_stepper/step.rb
Overview
One step in a session-backed wizard: just its identity and label. key is
coerced to a symbol so a step declared with either a symbol or string, and a
params[:id] that always arrives as a string, resolve to the same step.
Instance Attribute Summary collapse
-
#key ⇒ Object
readonly
Returns the value of attribute key.
-
#position ⇒ Object
readonly
Returns the value of attribute position.
-
#title ⇒ Object
readonly
Returns the value of attribute title.
Instance Method Summary collapse
-
#initialize(key:, title:, position:) ⇒ Step
constructor
A new instance of Step.
Constructor Details
#initialize(key:, title:, position:) ⇒ Step
Returns a new instance of Step.
7 8 9 |
# File 'app/controllers/concerns/glib/form_stepper/step.rb', line 7 def initialize(key:, title:, position:) super(key: key.to_sym, title: title, position: position) end |
Instance Attribute Details
#key ⇒ Object (readonly)
Returns the value of attribute key
6 7 8 |
# File 'app/controllers/concerns/glib/form_stepper/step.rb', line 6 def key @key end |
#position ⇒ Object (readonly)
Returns the value of attribute position
6 7 8 |
# File 'app/controllers/concerns/glib/form_stepper/step.rb', line 6 def position @position end |
#title ⇒ Object (readonly)
Returns the value of attribute title
6 7 8 |
# File 'app/controllers/concerns/glib/form_stepper/step.rb', line 6 def title @title end |